﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections;
using Telerik.Windows.Controls;
using System.Windows.Data;

namespace TestDataForm
{
    public partial class DataFormAlpha : UserControl
    {
        #region Properties

        public GridViewColumnCollection NavigationGridViewColumns
        {
            get
            {
                return this.NavigationGridView.Columns;
            }
        }

        #endregion

        #region DependencyProperties

        /// <summary> 
        /// ItemsSource Dependency Property 
        /// </summary> 
        public IEnumerable ItemsSource
        {
            get { return (IEnumerable)GetValue(ItemsSourceProperty); }
            set { SetValue(ItemsSourceProperty, value); }
        }

        /// <summary> 
        /// Identifies the ItemsSource Dependency Property. 
        /// </summary> 
        public static readonly DependencyProperty ItemsSourceProperty =
            DependencyProperty.Register("ItemsSource", typeof(IEnumerable),
            typeof(DataFormAlpha), new PropertyMetadata(null, OnItemsSourcePropertyChanged));

        private static void OnItemsSourcePropertyChanged(object sender, DependencyPropertyChangedEventArgs e)
        {
            DataFormAlpha control = sender as DataFormAlpha;
        }

        /// <summary>
        /// SelectedItem Dependency Property
        /// </summary>
        public object SelectedItem
        {
            get { return (object)GetValue(SelectedItemProperty); }
            set { SetValue(SelectedItemProperty, value); }
        }

        /// <summary>
        /// Identifies the SelectedItem Dependency Property
        /// </summary>
        public static readonly DependencyProperty SelectedItemProperty =
            DependencyProperty.Register("SelectedItem", typeof(object), typeof(DataFormAlpha), new PropertyMetadata(null, OnSelectedItemPropertyChanged));

        private static void OnSelectedItemPropertyChanged(object sender, DependencyPropertyChangedEventArgs e)
        {
            DataFormAlpha control = sender as DataFormAlpha;
        }

        /// <summary>
        /// Header Dependency Property
        /// </summary>
        public object Header
        {
            get { return (object)GetValue(HeaderProperty); }
            set { SetValue(HeaderProperty, value); }
        }

        /// <summary>
        /// Identifies the Header DependencyProperty
        /// </summary>
        public static readonly DependencyProperty HeaderProperty =
            DependencyProperty.Register("Header", typeof(object), typeof(DataFormAlpha), new PropertyMetadata(null, OnHeaderPropertyChanged));

        private static void OnHeaderPropertyChanged(object sender, DependencyPropertyChangedEventArgs e)
        {
            DataFormAlpha control = sender as DataFormAlpha;
            control.SetHeader();
        }

        /// <summary>
        /// DataFormIsInEditMode Dependency Property
        /// </summary>
        public bool IsInEditMode
        {
            get { return (Boolean)GetValue(IsInEditModeProperty); }
            set { SetValue(IsInEditModeProperty, value); }
        }

        /// <summary>
        /// Identifies the DataFormIsInEditMode Dependency Property
        /// </summary>
        public static readonly DependencyProperty IsInEditModeProperty =
            DependencyProperty.Register("IsInEditMode", typeof(Boolean), typeof(DataFormAlpha), new PropertyMetadata(false, OnIsInEditModePropertyChanged));

        private static void OnIsInEditModePropertyChanged(object sender, DependencyPropertyChangedEventArgs e)
        {
            DataFormAlpha control = sender as DataFormAlpha;
            control.ToggleEditMode();
            control.SetHeader();
        }

        /// <summary>
        /// DataFormWidth DependencyProperty
        /// </summary>
        public double DataFormWidth
        {
            get { return (double)GetValue(DataFormWidthProperty); }
            set { SetValue(DataFormWidthProperty, value); }
        }

        /// <summary>
        /// Identifies the DataFormWidth DependencyProperty
        /// </summary>
        public static readonly DependencyProperty DataFormWidthProperty =
            DependencyProperty.Register("DataFormWidth", typeof(double), typeof(DataFormAlpha), new PropertyMetadata(400.0, OnDataFormWidthPropertyChanged));

        private static void OnDataFormWidthPropertyChanged(object sender, DependencyPropertyChangedEventArgs e)
        {
            DataFormAlpha control = sender as DataFormAlpha;
            control.DataFormColumn.Width = new GridLength(control.DataFormWidth);
        }

        /// <summary> 
        /// DataFormReadOnlyTemplate Dependency Property 
        /// </summary> 
        public DataTemplate DataFormReadOnlyTemplate
        {
            get { return (DataTemplate)GetValue(DataFormReadOnlyTemplateProperty); }
            set { SetValue(DataFormReadOnlyTemplateProperty, value); }
        }

        /// <summary> 
        /// Identifies the DataFormReadOnlyTemplate Dependency Property. 
        /// </summary> 
        public static readonly DependencyProperty DataFormReadOnlyTemplateProperty =
            DependencyProperty.Register("DataFormReadOnlyTemplate", typeof(DataTemplate),
            typeof(DataFormAlpha), new PropertyMetadata(null, OnDataFormReadOnlyTemplatePropertyChanged));

        private static void OnDataFormReadOnlyTemplatePropertyChanged(object sender, DependencyPropertyChangedEventArgs e)
        {
            DataFormAlpha control = sender as DataFormAlpha;
            control.DataForm.ReadOnlyTemplate = control.DataFormReadOnlyTemplate;
        }

        /// <summary>
        /// DataFormEditTemplate Dependency Property
        /// </summary>
        public DataTemplate DataFormEditTemplate
        {
            get { return (DataTemplate)GetValue(DataFormEditTemplateProperty); }
            set { SetValue(DataFormEditTemplateProperty, value); }
        }

        /// <summary>
        /// Identifies the DataFormEditTemplate Dependency Property
        /// </summary>
        public static readonly DependencyProperty DataFormEditTemplateProperty =
            DependencyProperty.Register("DataFormEditTemplate", typeof(DataTemplate),
            typeof(DataFormAlpha), new PropertyMetadata(null, OnDataFormEditTemplatePropertyChanged));

        private static void OnDataFormEditTemplatePropertyChanged(object sender, DependencyPropertyChangedEventArgs e)
        {
            DataFormAlpha control = sender as DataFormAlpha;
            control.DataForm.EditTemplate = control.DataFormEditTemplate;
        }
        #endregion

        #region Ctor
        public DataFormAlpha()
        {
            InitializeComponent();
        }
        #endregion

        private void SetHeader()
        {
            if (this.IsInEditMode)
            {
                this.DataForm.Header = this.Header + " Edit";
            }
            else
            {
                this.DataForm.Header = this.Header + " Read-Only";
            }
        }

        private void ToggleEditMode()
        {
            if (this.IsInEditMode)
            {
                this.DataForm.BeginEdit();
            }
            else
            {
                this.DataForm.CommitEdit(true);
            }
        }

        private void DataForm_CurrentItemChanged(object sender, EventArgs e)
        {
            // By default the DataForm always changes from edit to read-only mode if changing the current item,
            // But this behaviour is not requested.
            if (IsInEditMode)
            {
                this.DataForm.BeginEdit();
            }
        }
    }
}
